"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupFiles = void 0;
const child_process_1 = require("child_process");
const fs = require("fs");
const vanillaAppFile = `
import React, { useCallback, useState } from "react";
import ReactDOM from "react-dom";

const App = ({ message }) => {
    const [count, setCount] = useState(0);
    const increment = useCallback(() => {
        setCount(count => count + 1);
    }, [count]);
    return(<>
        <h1>{message}</h1>
        <h2>Count: {count}</h2>
        <button onClick={increment}>Increment</button>
    </>)
};

ReactDOM.render(
  <App message="Hello World! Simple Counter App built on ESBuild + React"/>,
  document.getElementById('root')
);
`;
const typedAppFile = `
import React, { useCallback, useState } from "react";
import ReactDOM from "react-dom";

const App = ({ message }: { message: string}) => {
    const [count, setCount] = useState(0);
    const increment = useCallback(() => {
        setCount(count => count + 1);
    }, [count]);
    return(<>
        <h1>{message}</h1>
        <h2>Count: {count}</h2>
        <button onClick={increment}>Increment</button>
    </>)
};

ReactDOM.render(
  <App message="Hello World! Simple Counter App built on ESBuild + React + Typescript"/>,
  document.getElementById('root')
);
`;
function setupFiles(CLI, projectLanguage) {
    CLI.log(`Setting up template files with ${projectLanguage} config`);
    try {
        if (projectLanguage === "javascript") {
            fs.writeFileSync("./src/app.js", vanillaAppFile);
        }
        else {
            child_process_1.execSync("npx tsc --init --rootDir src --jsx react");
            fs.writeFileSync("./src/app.tsx", typedAppFile);
        }
    }
    catch (err) {
        CLI.error(`File Setup: ${err}`, { exit: 1 });
    }
}
exports.setupFiles = setupFiles;
