"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updatePackageJson = void 0;
const fs = require("fs");
const updateVanillaContent = `
  "scripts": {
    "build": "esbuild src/app.js --bundle --minify --sourcemap --outfile=public/bundle.js"
  }
`;
const updateTypedContent = `
  "scripts": {
    "build": "esbuild src/app.tsx --bundle --minify --sourcemap --outfile=public/bundle.js"
  },
`;
function updatePackageJson(CLI, projectLanguage) {
    CLI.log(`Insert custom build script into package.json using ${projectLanguage} config`);
    try {
        const content = projectLanguage === "javascript"
            ? updateVanillaContent
            : updateTypedContent;
        const data = fs.readFileSync("package.json").toString().split("\n");
        const linesToAdd = content.split("\n").filter((line) => line);
        data.splice(5, 0, ...linesToAdd);
        const text = data.join("\n");
        fs.writeFileSync("package.json", text);
    }
    catch (err) {
        CLI.error(`Update package.json: ${err}`, { exit: 1 });
    }
}
exports.updatePackageJson = updatePackageJson;
