"use strict";
const command_1 = require("@oclif/command");
const inquirer = require("inquirer");
const installDependencies_1 = require("./actions/installDependencies");
const openFolder_1 = require("./actions/openFolder");
const setupFiles_1 = require("./actions/setupFiles");
const setupFolder_1 = require("./actions/setupFolder");
const updatePackageJson_1 = require("./actions/updatePackageJson");
const language = command_1.flags.build({
    char: "l",
    description: 'choice of language ["typescript", "javascript"]',
});
const packageManager = command_1.flags.build({
    char: "p",
    description: 'choice of package manager ["yarn", "npm"]',
});
class CreateReactCli extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(CreateReactCli);
        let projectLanguage = "typescript";
        let packageManagerName;
        if (!args.folder)
            this.error("Missing folder name", { exit: 1 });
        if (flags.language) {
            projectLanguage = flags.language;
        }
        else {
            const input = await inquirer.prompt([
                {
                    name: "project language",
                    message: "select a language",
                    type: "list",
                    choices: [{ name: "typescript" }, { name: "javascript" }],
                },
            ]);
            projectLanguage = input["project language"];
        }
        if (flags.packageManager) {
            packageManagerName = flags.packageManager;
        }
        else {
            const input = await inquirer.prompt([
                {
                    name: "package manager",
                    message: "select a package manager",
                    type: "list",
                    choices: [{ name: "yarn" }, { name: "npm" }],
                },
            ]);
            packageManagerName = input["package manager"];
        }
        this.log("Starting to setup project...");
        setupFolder_1.setupFolder(this, args.folder);
        openFolder_1.openFolder(this, args.folder);
        installDependencies_1.installDependencies(this, packageManagerName, projectLanguage);
        setupFolder_1.setupFolder(this, "src");
        setupFiles_1.setupFiles(this, projectLanguage);
        updatePackageJson_1.updatePackageJson(this, projectLanguage);
        // TODO: support .
        // TODO: add jest
        // TODO: add readme, gitignore
        this.log("Project setup complete!");
    }
}
CreateReactCli.description = "A CLI for generating esbuild projects with your choice of language and package manager.";
CreateReactCli.flags = {
    version: command_1.flags.version({ char: "v" }),
    help: command_1.flags.help({ char: "h" }),
    language: language(),
    packageManager: packageManager(),
};
CreateReactCli.args = [{ name: "folder" }];
module.exports = CreateReactCli;
